---
title: <span class="badge object-type-scalar"></span> MilligramPerCubicMeter
---
# <span class="badge object-type-scalar"></span> MilligramPerCubicMeter

Concentration: milligram per cubic meter (mg/m³)

## Definition

```python
# Concentration: milligram per cubic meter (mg/m³)
MilligramPerCubicMeter: typing.Literal["conmgm3"] = "conmgm3"
```
